@@ -329,6 +329,19 @@ action_smime_sign_cb (GtkToggleAction *action,
 	e_html_editor_view_set_changed (view, TRUE);
 }
 
+static void
+action_unicode_smileys_cb (GtkToggleAction *action,
+                           EMsgComposer *composer)
+{
+	EHTMLEditor *editor;
+	EHTMLEditorView *view;
+
+	editor = e_msg_composer_get_editor (composer);
+	view = e_html_editor_get_view (editor);
+	e_html_editor_view_set_unicode_smileys (view,
+		gtk_toggle_action_get_active (action));
+}
+
 static void
 composer_actions_toolbar_option_toggled_cb (GtkToggleAction *toggle_action,
 					    EMsgComposer *composer)
@@ -558,6 +571,14 @@ static GtkToggleActionEntry toggle_entries[] = {
 	  NULL,
 	  FALSE },
 
+	{ "unicode-smileys",
+	  NULL,
+	  N_("Unicode smileys"),
+	  NULL,
+	  N_("Use Unicode characters for smileys."),
+	  G_CALLBACK (action_unicode_smileys_cb),
+	  FALSE },
+
 	{ "view-bcc",
 	  NULL,
 	  N_("_Bcc Field"),
@@ -574,6 +595,14 @@ static GtkToggleActionEntry toggle_entries[] = {
 	  NULL,  /* Handled by property bindings */
 	  FALSE },
 
+	{ "view-from-override",
+	  NULL,
+	  N_("_From Override Field"),
+	  NULL,
+	  N_("Toggles whether the From override field to change name or email address is displayed"),
+	  NULL,  /* Handled by property bindings */
+	  FALSE },
+
 	{ "view-reply-to",
 	  NULL,
 	  N_("_Reply-To Field"),
@@ -643,19 +672,19 @@ e_composer_actions_init (EMsgComposer *composer)
 
 	#define init_toolbar_option(x, always_visible)	\
 		gtk_action_set_visible (ACTION (TOOLBAR_ ## x), always_visible); \
-		g_object_bind_property ( \
+		e_binding_bind_property ( \
 			ACTION (x), "active", \
 			ACTION (TOOLBAR_ ## x), "active", \
 			G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL); \
-		g_object_bind_property ( \
+		e_binding_bind_property ( \
 			ACTION (x), "label", \
 			ACTION (TOOLBAR_ ## x), "label", \
 			G_BINDING_SYNC_CREATE); \
-		g_object_bind_property ( \
+		e_binding_bind_property ( \
 			ACTION (x), "tooltip", \
 			ACTION (TOOLBAR_ ## x), "tooltip", \
 			G_BINDING_SYNC_CREATE); \
-		g_object_bind_property ( \
+		e_binding_bind_property ( \
 			ACTION (x), "sensitive", \
 			ACTION (TOOLBAR_ ## x), "sensitive", \
 			G_BINDING_SYNC_CREATE); \
@@ -701,32 +730,32 @@ e_composer_actions_init (EMsgComposer *composer)
 		g_object_unref (gcr_gnupg_icon);
 	}
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		view, "html-mode",
 		ACTION (PICTURE_GALLERY), "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		view, "editable",
 		e_html_editor_get_action (editor, "edit-menu"), "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		view, "editable",
 		e_html_editor_get_action (editor, "format-menu"), "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		view, "editable",
 		e_html_editor_get_action (editor, "insert-menu"), "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		view, "editable",
 		e_html_editor_get_action (editor, "options-menu"), "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		view, "editable",
 		e_html_editor_get_action (editor, "picture-gallery"), "sensitive",
 		G_BINDING_SYNC_CREATE);
