@@ -277,7 +277,7 @@ cal_source_config_init_candidate (ESourceConfig *config,
 	extension_name = e_source_config_get_backend_extension_name (config);
 	extension = e_source_get_extension (scratch_source, extension_name);
 
-	g_object_bind_property_full (
+	e_binding_bind_property_full (
 		extension, "color",
 		priv->color_button, "color",
 		G_BINDING_BIDIRECTIONAL |
@@ -422,7 +422,7 @@ e_cal_source_config_add_offline_toggle (ECalSourceConfig *config,
 		E_SOURCE_CONFIG (config), scratch_source, NULL, widget);
 	gtk_widget_show (widget);
 
-	g_object_bind_property (
+	e_binding_bind_property (
 		extension, "stay-synchronized",
 		widget, "active",
 		G_BINDING_BIDIRECTIONAL |
