@@ -43,6 +43,8 @@ struct _EHTMLEditorHRuleDialogPrivate {
 	GtkWidget *shaded_check;
 
 	WebKitDOMHTMLHRElement *hr_element;
+
+	EHTMLEditorViewHistoryEvent *history_event;
 };
 
 G_DEFINE_TYPE (
@@ -198,8 +200,32 @@ static void
 html_editor_hrule_dialog_hide (GtkWidget *widget)
 {
 	EHTMLEditorHRuleDialogPrivate *priv;
+	EHTMLEditorViewHistoryEvent *ev;
 
 	priv = E_HTML_EDITOR_HRULE_DIALOG_GET_PRIVATE (widget);
+	ev = priv->history_event;
+
+	if (ev) {
+		EHTMLEditorHRuleDialog *dialog;
+		EHTMLEditor *editor;
+		EHTMLEditorSelection *selection;
+		EHTMLEditorView *view;
+
+		dialog = E_HTML_EDITOR_HRULE_DIALOG (widget);
+		editor = e_html_editor_dialog_get_editor (E_HTML_EDITOR_DIALOG (dialog));
+		view = e_html_editor_get_view (editor);
+		selection = e_html_editor_view_get_selection (view);
+
+		ev->data.dom.to = webkit_dom_node_clone_node (
+			WEBKIT_DOM_NODE (priv->hr_element), FALSE);
+
+		e_html_editor_selection_get_selection_coordinates (
+			selection, &ev->after.start.x, &ev->after.start.y, &ev->after.end.x, &ev->after.end.y);
+		e_html_editor_view_insert_new_history_event (view, ev);
+
+		if (!ev->data.dom.from)
+			g_object_unref (priv->hr_element);
+	}
 
 	priv->hr_element = NULL;
 
@@ -211,63 +237,52 @@ html_editor_hrule_dialog_show (GtkWidget *widget)
 {
 	EHTMLEditorHRuleDialog *dialog;
 	EHTMLEditor *editor;
-	EHTMLEditorSelection *editor_selection;
+	EHTMLEditorSelection *selection;
 	EHTMLEditorView *view;
 
 	WebKitDOMDocument *document;
-	WebKitDOMDOMWindow *window;
-	WebKitDOMDOMSelection *selection;
-	WebKitDOMElement *rule;
-	WebKitDOMRange *range;
-	WebKitDOMNode *node;
 
 	dialog = E_HTML_EDITOR_HRULE_DIALOG (widget);
 	editor = e_html_editor_dialog_get_editor (E_HTML_EDITOR_DIALOG (dialog));
 	view = e_html_editor_get_view (editor);
-	editor_selection = e_html_editor_view_get_selection (view);
+	selection = e_html_editor_view_get_selection (view);
 
-	document = webkit_web_view_get_dom_document (
-			WEBKIT_WEB_VIEW (view));
-	window = webkit_dom_document_get_default_view (document);
-	selection = webkit_dom_dom_window_get_selection (window);
-	if (webkit_dom_dom_selection_get_range_count (selection) < 1) {
-		GTK_WIDGET_CLASS (e_html_editor_hrule_dialog_parent_class)->show (widget);
-		return;
+	if (!e_html_editor_view_is_undo_redo_in_progress (view)) {
+		EHTMLEditorViewHistoryEvent *ev;
+
+		ev = g_new0 (EHTMLEditorViewHistoryEvent, 1);
+		ev->type = HISTORY_HRULE_DIALOG;
+
+		e_html_editor_selection_get_selection_coordinates (
+			selection, &ev->before.start.x, &ev->before.start.y, &ev->before.end.x, &ev->before.end.y);
+		if (dialog->priv->hr_element)
+			ev->data.dom.from = webkit_dom_node_clone_node (
+				WEBKIT_DOM_NODE (dialog->priv->hr_element), FALSE);
+		else
+			ev->data.dom.from = NULL;
+		dialog->priv->history_event = ev;
 	}
 
-	range = webkit_dom_dom_selection_get_range_at (selection, 0, NULL);
-	node = webkit_dom_range_get_common_ancestor_container (range, NULL);
-	if (node && !WEBKIT_DOM_IS_HTMLHR_ELEMENT (node)) {
-		rule = e_html_editor_dom_node_find_parent_element (node, "A");
-		if (rule && !WEBKIT_DOM_IS_HTML_ANCHOR_ELEMENT (rule))
-			rule = NULL;
-	} else
-		rule = WEBKIT_DOM_ELEMENT (node);
+	if (!dialog->priv->hr_element) {
+		WebKitDOMElement *selection_start, *parent, *rule;
 
-	if (!rule) {
-		WebKitDOMElement *caret, *parent, *element;
+		document = webkit_web_view_get_dom_document (WEBKIT_WEB_VIEW (view));
+		e_html_editor_selection_save (selection);
 
-		caret = e_html_editor_selection_save_caret_position (editor_selection);
-
-		parent = webkit_dom_node_get_parent_element (WEBKIT_DOM_NODE (caret));
-		element = caret;
-
-		while (!WEBKIT_DOM_IS_HTML_BODY_ELEMENT (parent)) {
-			element = parent;
-			parent = webkit_dom_node_get_parent_element (
-				WEBKIT_DOM_NODE (parent));
-		}
+		selection_start = webkit_dom_document_get_element_by_id (
+			document, "-x-evo-selection-start-marker");
+		parent = get_parent_block_element (WEBKIT_DOM_NODE (selection_start));
 
 		rule = webkit_dom_document_create_element (document, "HR", NULL);
 
 		/* Insert horizontal rule into body below the caret */
 		webkit_dom_node_insert_before (
-			WEBKIT_DOM_NODE (parent),
+			webkit_dom_node_get_parent_node (WEBKIT_DOM_NODE (parent)),
 			WEBKIT_DOM_NODE (rule),
-			webkit_dom_node_get_next_sibling (WEBKIT_DOM_NODE (element)),
+			webkit_dom_node_get_next_sibling (WEBKIT_DOM_NODE (parent)),
 			NULL);
 
-		e_html_editor_selection_clear_caret_position_marker (editor_selection);
+		e_html_editor_selection_restore (selection);
 
 		dialog->priv->hr_element = WEBKIT_DOM_HTMLHR_ELEMENT (rule);
 
@@ -290,8 +305,6 @@ html_editor_hrule_dialog_show (GtkWidget *widget)
 
 		e_html_editor_view_set_changed (view, TRUE);
 	} else {
-		dialog->priv->hr_element = WEBKIT_DOM_HTMLHR_ELEMENT (rule);
-
 		html_editor_hrule_dialog_get_alignment (dialog);
 		html_editor_hrule_dialog_get_size (dialog);
 		html_editor_hrule_dialog_get_width (dialog);
@@ -429,3 +442,17 @@ e_html_editor_hrule_dialog_new (EHTMLEditor *editor)
 			"title", _("Rule properties"),
 			NULL));
 }
+
+void
+e_html_editor_hrule_dialog_show (EHTMLEditorHRuleDialog *dialog,
+                                 WebKitDOMNode *rule)
+{
+	EHTMLEditorHRuleDialogClass *class;
+
+	g_return_if_fail (E_IS_HTML_EDITOR_HRULE_DIALOG (dialog));
+
+	dialog->priv->hr_element = rule ? WEBKIT_DOM_HTMLHR_ELEMENT (rule) : NULL;
+
+	class = E_HTML_EDITOR_HRULE_DIALOG_GET_CLASS (dialog);
+	GTK_WIDGET_CLASS (class)->show (GTK_WIDGET (dialog));
+}
