@@ -53,6 +53,14 @@
 	(G_TYPE_INSTANCE_GET_CLASS \
 	((obj), E_TYPE_HTML_EDITOR_VIEW, EHTMLEditorViewClass))
 
+#define UNICODE_ZERO_WIDTH_SPACE "\xe2\x80\x8b"
+#define UNICODE_NBSP "\xc2\xa0"
+
+#define SPACES_PER_INDENTATION 4
+#define SPACES_PER_LIST_LEVEL 8
+#define MINIMAL_PARAGRAPH_WIDTH 5
+#define TAB_LENGTH 8
+
 G_BEGIN_DECLS
 
 typedef struct _EHTMLEditorView EHTMLEditorView;
@@ -106,7 +114,8 @@ enum EHTMLEditorViewHistoryEventType {
 	HISTORY_TABLE_DIALOG,
 	HISTORY_TABLE_INPUT,
 	HISTORY_UNDERLINE,
-	HISTORY_WRAP
+	HISTORY_WRAP,
+	HISTORY_UNQUOTE
 };
 
 typedef struct {
@@ -235,6 +244,8 @@ void		e_html_editor_view_force_spell_check_for_current_paragraph
 						(EHTMLEditorView *view);
 void		e_html_editor_view_force_spell_check
 						(EHTMLEditorView *view);
+void		e_html_editor_view_force_spell_check_in_viewport
+						(EHTMLEditorView *view);
 void		e_html_editor_view_quote_plain_text_element_after_wrapping
 						(WebKitDOMDocument *document,
 						 WebKitDOMElement *element,
@@ -246,6 +257,9 @@ void		remove_image_attributes_from_element
 						(WebKitDOMElement *element);
 gboolean	e_html_editor_view_is_message_from_draft
 						(EHTMLEditorView *view);
+void		e_html_editor_view_set_is_editting_message
+						(EHTMLEditorView *view,
+						 gboolean value);
 void		e_html_editor_view_set_is_message_from_draft
 						(EHTMLEditorView *view,
 						 gboolean value);
@@ -257,9 +271,6 @@ gboolean	e_html_editor_view_is_message_from_edit_as_new
 void		e_html_editor_view_set_is_message_from_edit_as_new
 						(EHTMLEditorView *view,
 						 gboolean value);
-void		e_html_editor_view_set_remove_initial_input_line
-						(EHTMLEditorView *view,
-						 gboolean value);
 void		e_html_editor_view_insert_quoted_text
 						(EHTMLEditorView *view,
 						 const gchar *text);
