@@ -25,7 +25,7 @@ main (gint argc,
       gchar **argv)
 {
 	ESourceRegistry *registry;
-	EMailAutoconfig *autoconfig;
+	EMailAutoconfig *autoconfig = NULL;
 	GError *error = NULL;
 
 	if (argc < 2) {
@@ -54,7 +54,7 @@ main (gint argc,
 
 	e_mail_autoconfig_dump_results (autoconfig);
 
-	g_object_unref (autoconfig);
+	g_clear_object (&autoconfig);
 
 	return EXIT_SUCCESS;
 }
